@@ -26,6 +26,7 @@ from .consts import (
     fac,
     fap,
     fbp,
+    resonant,
     num_blocks_curves_fax,
     num_blocks_curves_fbp,
     num_coeffs_dsp_modules,
@@ -1688,8 +1689,12 @@ class BaseDRS:
                 vars_dict["ps_setpoint"] = vars_dict["ps_setpoint"][:-1] + "V"
                 vars_dict["ps_reference"] = vars_dict["ps_reference"][:-1] + "V"
         else:
-            vars_dict["ps_setpoint"] = vars_dict["ps_setpoint"][:-1] + "%"
-            vars_dict["ps_reference"] = vars_dict["ps_reference"][:-1] + "%"
+            if (vars_dict["status"]["model"] == "RESONANT_SWLS"):
+                vars_dict["ps_setpoint"] = vars_dict["ps_setpoint"][:-1] + "Hz"
+                vars_dict["ps_reference"] = vars_dict["ps_reference"][:-1] + "Hz"
+            else:
+                vars_dict["ps_setpoint"] = vars_dict["ps_setpoint"][:-1] + "%"
+                vars_dict["ps_reference"] = vars_dict["ps_reference"][:-1] + "%"
 
         vars_dict["siggen_type"] = common.sig_gen_types[int(vars_dict["siggen_type"])]
         vars_dict["wfmref_sync_mode"] = common.wfmref_sync_modes[
@@ -1765,6 +1770,7 @@ class BaseDRS:
         if length is None:
             length = 255 + sum([data["size"] for data in template.values()])
 
+
         # Dynamically obtaining transfer sizes incurs a 70 uS penalty per execution
 
         vals = self._transfer(
@@ -1835,6 +1841,7 @@ class BaseDRS:
             vars_dict["iib_is_alarms_raw"] = vars_dict.pop("iib_alarms_is")
             vars_dict["iib_is_interlocks_raw"] = vars_dict.pop("iib_interlocks_is")
 
+
             vars_dict["iib_is_interlocks"] = self.decode_interlocks(
                 vars_dict["iib_is_interlocks_raw"],
                 fac.list_acdc_iib_is_interlocks,
@@ -1854,9 +1861,9 @@ class BaseDRS:
                 vars_dict["iib_cmd_alarms_raw"],
                 fac.list_acdc_iib_cmd_alarms,
             )
-
         return vars_dict
 
+
     def read_vars_fac_dcdc(self, iib: bool = True) -> dict:
         """Reads FAC DCDC power supply variables
 
@@ -2179,6 +2186,7 @@ class BaseDRS:
         """
         Read FAC 2P DCDC IMAS specific power supply variables
 
+
         Returns
         -------
         dict
@@ -2190,7 +2198,24 @@ class BaseDRS:
             fac.list_2p_dcdc_imas_hard_interlocks,
         )
 
+    def read_vars_swls_resonant_converter(self) -> dict:
+        """
+        Reads SWLS resonant converter power supply variables
+
+
+        Returns
+        -------
+        dict
+            Dictionary with power supply variables
+        """
+        return self._read_vars_generic(
+            resonant.bsmp,
+            resonant.list_soft_interlocks,
+            resonant.list_hard_interlocks,
+        )
+
     def check_param_bank(self, param_file: str):
+
         ps_param_list = []
 
         # max_sampling_freq = 600000
@@ -2253,6 +2278,14 @@ class BaseDRS:
             self.set_dsp_coeffs(3, dsp_id, [kp, ki, 0.95, -0.95])
         return {"kp": kp, "ki": ki}
 
+    def store_dsp_modules_bank_csv(self, bank):
+        filename = input("Digite o nome do arquivo: ")
+        with open(filename + ".csv", "w", newline="") as f:
+            writer = csv.writer(f, delimiter=",")
+            for dsp_module, values in bank.items():
+                for i, coef in enumerate(values["coeffs"]):
+                    writer.writerow([dsp_module, values["class"], i] + coef)
+
     def config_dsp_modules_drs_fap_tests(self):
         kp_load = 0
         ki_load = 20.95
@@ -2321,14 +2354,15 @@ class BaseDRS:
                             ].append(dsp_coeffs)
 
                 if return_floathex:
-                    dsp_modules_bank[dsp_classes_names[dsp_class]]["coeffs"] = [
+                    dsp_modules_bank[dsp_classes_names[dsp_class]]["coeffs"].append([
                         dsp_coeffs,
                         dsp_coeffs_hex,
-                    ]
+                    ])
                 else:
-                    dsp_modules_bank[dsp_classes_names[dsp_class]][
-                        "coeffs"
-                    ] = dsp_coeffs
+                    dsp_modules_bank[dsp_classes_names[dsp_class]]["coeffs"].append(
+                        dsp_coeffs
+                    )
+
 
         return dsp_modules_bank
 
@@ -2386,6 +2420,7 @@ class BaseDRS:
 
         Returns
         -------
+
         dict[dsp_class_name] = {"class":int, "coeffs":[float]}
         """
         dsp_coeffs_from_csv = {}
