@@ -85,6 +85,7 @@ list_dcdc_hard_interlocks = [
     "IIB Interlock",
     "External Interlock",
     "Rack Interlock",
+    "Leakage_Overcurrent",
 ]
 
 list_dcdc_iib_interlocks = [
@@ -104,7 +105,6 @@ list_dcdc_iib_interlocks = [
     "Bottom Driver 2 Error",
     "Inductors Overtemperature",
     "Heat-Sink Overtemperature",
-    "Ground Leakage Overcurrent",
     "Board IIB Overtemperature",
     "Module Overhumidity",
 ]
@@ -120,7 +120,6 @@ list_dcdc_iib_alarms = [
     "Driver 2 Overcurrent",
     "Inductors Overtemperature",
     "Heat-Sink Overtemperature",
-    "Ground Leakage Overcurrent",
     "Board IIB Overtemperature",
     "Module Overhumidity",
 ]
@@ -239,6 +238,7 @@ list_dcdc_ema_hard_interlocks = [
     "Load Waterflow",
     "Load Overtemperature",
     "IIB Itlk",
+    "Leakage_Overcurrent",
 ]
 
 list_dcdc_ema_iib_interlocks = [
@@ -258,7 +258,6 @@ list_dcdc_ema_iib_interlocks = [
     "Bottom Driver 2 Error",
     "Inductors Overtemperature",
     "Heat-Sink Overtemperature",
-    "Ground Leakage Overcurrent",
     "Board IIB Overtemperature",
     "Module Overhumidity",
 ]
@@ -274,7 +273,6 @@ list_dcdc_ema_iib_alarms = [
     "Driver 2 Overcurrent",
     "Inductors Overtemperature",
     "Heat-Sink Overtemperature",
-    "Ground Leakage Overcurrent",
     "Board IIB Overtemperature",
     "Module Overhumidity",
 ]
@@ -341,17 +339,17 @@ bsmp_dcdc = {
     "i_load2": {"addr": 35, "format": "f", "size": 4, "egu": "A"},
     "v_capacitor_bank": {"addr": 36, "format": "f", "size": 4, "egu": "V"},
     "duty_cycle": {"addr": 37, "format": "f", "size": 4, "egu": "p.u."},
-    "v_input_iib": {"addr": 38, "format": "f", "size": 4, "egu": "V"},
-    "i_input_iib": {"addr": 39, "format": "f", "size": 4, "egu": "A"},
-    "i_output_iib": {"addr": 40, "format": "f", "size": 4, "egu": "A"},
-    "temp_igbts_1_iib": {"addr": 41, "format": "f", "size": 4, "egu": "°C"},
-    "temp_igbts_2_iib": {"addr": 42, "format": "f", "size": 4, "egu": "°C"},
-    "temp_inductor_iib": {"addr": 43, "format": "f", "size": 4, "egu": "°C"},
-    "temp_heatsink_iib": {"addr": 44, "format": "f", "size": 4, "egu": "°C"},
-    "v_driver_iib": {"addr": 45, "format": "f", "size": 4, "egu": "V"},
-    "i_driver_1_iib": {"addr": 46, "format": "f", "size": 4, "egu": "A"},
-    "i_driver_2_iib": {"addr": 47, "format": "f", "size": 4, "egu": "A"},
-    "i_leakage_iib": {"addr": 48, "format": "f", "size": 4, "egu": "A"},
+    "i_leakage": {"addr": 38, "format": "f", "size": 4, "egu": "A"},
+    "v_input_iib": {"addr": 39, "format": "f", "size": 4, "egu": "V"},
+    "i_input_iib": {"addr": 40, "format": "f", "size": 4, "egu": "A"},
+    "i_output_iib": {"addr": 41, "format": "f", "size": 4, "egu": "A"},
+    "temp_igbts_1_iib": {"addr": 42, "format": "f", "size": 4, "egu": "°C"},
+    "temp_igbts_2_iib": {"addr": 43, "format": "f", "size": 4, "egu": "°C"},
+    "temp_inductor_iib": {"addr": 44, "format": "f", "size": 4, "egu": "°C"},
+    "temp_heatsink_iib": {"addr": 45, "format": "f", "size": 4, "egu": "°C"},
+    "v_driver_iib": {"addr": 46, "format": "f", "size": 4, "egu": "V"},
+    "i_driver_1_iib": {"addr": 47, "format": "f", "size": 4, "egu": "A"},
+    "i_driver_2_iib": {"addr": 48, "format": "f", "size": 4, "egu": "A"},
     "temp_board_iib": {"addr": 49, "format": "f", "size": 4, "egu": "°C"},
     "rh_iib": {"addr": 50, "format": "f", "size": 4, "egu": "%"},
     "iib_interlocks": {"addr": 51, "format": "I", "size": 4, "egu": ""},
@@ -363,21 +361,21 @@ bsmp_dcdc_ema = {
     "i_load": {"addr": 33, "format": "f", "size": 4, "egu": "A"},
     "v_dclink": {"addr": 34, "format": "f", "size": 4, "egu": "V"},
     "duty_cycle": {"addr": 35, "format": "f", "size": 4, "egu": "p.u."},
-    "v_input_iib": {"addr": 36, "format": "f", "size": 4, "egu": "V"},
-    "i_input_iib": {"addr": 37, "format": "f", "size": 4, "egu": "A"},
-    "i_output_iib": {"addr": 38, "format": "f", "size": 4, "egu": "A"},
-    "temp_igbts_1_iib": {"addr": 39, "format": "f", "size": 4, "egu": "°C"},
-    "temp_igbts_2_iib": {"addr": 40, "format": "f", "size": 4, "egu": "°C"},
-    "temp_inductor_iib": {"addr": 41, "format": "f", "size": 4, "egu": "°C"},
-    "temp_heatsink_iib": {"addr": 42, "format": "f", "size": 4, "egu": "°C"},
-    "v_driver_iib": {"addr": 43, "format": "f", "size": 4, "egu": "V"},
-    "i_driver_1_iib": {"addr": 44, "format": "f", "size": 4, "egu": "A"},
-    "i_driver_2_iib": {"addr": 45, "format": "f", "size": 4, "egu": "A"},
-    "i_leakage_iib": {"addr": 46, "format": "f", "size": 4, "egu": "A"},
+    "i_leakage": {"addr": 36, "format": "f", "size": 4, "egu": "A"},
+    "v_input_iib": {"addr": 37, "format": "f", "size": 4, "egu": "V"},
+    "i_input_iib": {"addr": 38, "format": "f", "size": 4, "egu": "A"},
+    "i_output_iib": {"addr": 39, "format": "f", "size": 4, "egu": "A"},
+    "temp_igbts_1_iib": {"addr": 40, "format": "f", "size": 4, "egu": "°C"},
+    "temp_igbts_2_iib": {"addr": 41, "format": "f", "size": 4, "egu": "°C"},
+    "temp_inductor_iib": {"addr": 42, "format": "f", "size": 4, "egu": "°C"},
+    "temp_heatsink_iib": {"addr": 43, "format": "f", "size": 4, "egu": "°C"},
+    "v_driver_iib": {"addr": 44, "format": "f", "size": 4, "egu": "V"},
+    "i_driver_1_iib": {"addr": 45, "format": "f", "size": 4, "egu": "A"},
+    "i_driver_2_iib": {"addr": 46, "format": "f", "size": 4, "egu": "A"},
     "temp_board_iib": {"addr": 47, "format": "f", "size": 4, "egu": "°C"},
     "rh_iib": {"addr": 48, "format": "f", "size": 4, "egu": "%"},
-    "iib_interlocks": {"addr": 49, "format": "f", "size": 4, "egu": ""},
-    "iib_alarms": {"addr": 50, "format": "f", "size": 4, "egu": ""},
+    "iib_interlocks": {"addr": 49, "format": "I", "size": 4, "egu": ""},
+    "iib_alarms": {"addr": 50, "format": "I", "size": 4, "egu": ""},
     "ps_alarms": {"addr": 51, "format": "I", "size": 4, "egu": ""},
 }
 
