@@ -220,18 +220,18 @@ bsmp_4p = {
     "duty_cycle_2_3": {"addr": 55, "format": "f", "size": 4, "egu": "p.u."},
     "duty_cycle_1_4": {"addr": 56, "format": "f", "size": 4, "egu": "p.u."},
     "duty_cycle_2_4": {"addr": 57, "format": "f", "size": 4, "egu": "p.u."},
-    "v_input_iib_1": {"addr": 58, "format": "f", "size": 4, "egu": "V"},
-    "v_output_iib_1": {"addr": 59, "format": "f", "size": 4, "egu": "V"},
-    "i_igbt_1_iib_1": {"addr": 60, "format": "f", "size": 4, "egu": "A"},
-    "i_igbt_2_iib_1": {"addr": 61, "format": "f", "size": 4, "egu": "A"},
-    "temp_igbt_1_iib_1": {"addr": 62, "format": "f", "size": 4, "egu": "°C"},
-    "temp_igbt_2_iib_1": {"addr": 63, "format": "f", "size": 4, "egu": "°C"},
-    "v_driver_iib_1": {"addr": 64, "format": "f", "size": 4, "egu": "V"},
-    "i_driver_1_iib_1": {"addr": 65, "format": "f", "size": 4, "egu": "A"},
-    "i_driver_2_iib_1": {"addr": 66, "format": "f", "size": 4, "egu": "A"},
-    "temp_inductor_iib_1": {"addr": 67, "format": "f", "size": 4, "egu": "°C"},
-    "temp_heatsink_iib_1": {"addr": 68, "format": "f", "size": 4, "egu": "°C"},
-    "i_leakage_iib_1": {"addr": 69, "format": "f", "size": 4, "egu": "A"},
+    "i_leakage": {"addr": 58, "format": "f", "size": 4, "egu": "A"},
+    "v_input_iib_1": {"addr": 59, "format": "f", "size": 4, "egu": "V"},
+    "v_output_iib_1": {"addr": 60, "format": "f", "size": 4, "egu": "V"},
+    "i_igbt_1_iib_1": {"addr": 61, "format": "f", "size": 4, "egu": "A"},
+    "i_igbt_2_iib_1": {"addr": 62, "format": "f", "size": 4, "egu": "A"},
+    "temp_igbt_1_iib_1": {"addr": 63, "format": "f", "size": 4, "egu": "°C"},
+    "temp_igbt_2_iib_1": {"addr": 64, "format": "f", "size": 4, "egu": "°C"},
+    "v_driver_iib_1": {"addr": 65, "format": "f", "size": 4, "egu": "V"},
+    "i_driver_1_iib_1": {"addr": 66, "format": "f", "size": 4, "egu": "A"},
+    "i_driver_2_iib_1": {"addr": 67, "format": "f", "size": 4, "egu": "A"},
+    "temp_inductor_iib_1": {"addr": 68, "format": "f", "size": 4, "egu": "°C"},
+    "temp_heatsink_iib_1": {"addr": 69, "format": "f", "size": 4, "egu": "°C"},
     "temp_board_iib_1": {"addr": 70, "format": "f", "size": 4, "egu": "°C"},
     "rh_iib_1": {"addr": 71, "format": "f", "size": 4, "egu": "%"},
     "iib_interlocks_1": {"addr": 72, "format": "I", "size": 4, "egu": ""},
@@ -247,44 +247,41 @@ bsmp_4p = {
     "i_driver_2_iib_2": {"addr": 82, "format": "f", "size": 4, "egu": "A"},
     "temp_inductor_iib_2": {"addr": 83, "format": "f", "size": 4, "egu": "°C"},
     "temp_heatsink_iib_2": {"addr": 84, "format": "f", "size": 4, "egu": "°C"},
-    "i_leakage_iib_2": {"addr": 85, "format": "f", "size": 4, "egu": "A"},
-    "temp_board_iib_2": {"addr": 86, "format": "f", "size": 4, "egu": "°C"},
-    "rh_iib_2": {"addr": 87, "format": "f", "size": 4, "egu": "%"},
-    "iib_interlocks_2": {"addr": 88, "format": "I", "size": 4, "egu": ""},
-    "iib_alarms_2": {"addr": 89, "format": "I", "size": 4, "egu": ""},
-    "v_input_iib_3": {"addr": 90, "format": "f", "size": 4, "egu": "V"},
-    "v_output_iib_3": {"addr": 91, "format": "f", "size": 4, "egu": "V"},
-    "i_igbt_1_iib_3": {"addr": 92, "format": "f", "size": 4, "egu": "A"},
-    "i_igbt_2_iib_3": {"addr": 93, "format": "f", "size": 4, "egu": "A"},
-    "temp_igbt_1_iib_3": {"addr": 94, "format": "f", "size": 4, "egu": "°C"},
-    "temp_igbt_2_iib_3": {"addr": 95, "format": "f", "size": 4, "egu": "°C"},
-    "v_driver_iib_3": {"addr": 96, "format": "f", "size": 4, "egu": "V"},
-    "i_driver_1_iib_3": {"addr": 97, "format": "f", "size": 4, "egu": "A"},
-    "i_driver_2_iib_3": {"addr": 98, "format": "f", "size": 4, "egu": "A"},
-    "temp_inductor_iib_3": {"addr": 99, "format": "f", "size": 4, "egu": "°C"},
-    "temp_heatsink_iib_3": {"addr": 100, "format": "f", "size": 4, "egu": "°C"},
-    "i_leakage_iib_3": {"addr": 101, "format": "f", "size": 4, "egu": "A"},
-    "temp_board_iib_3": {"addr": 102, "format": "f", "size": 4, "egu": "°C"},
-    "rh_iib_3": {"addr": 103, "format": "f", "size": 4, "egu": "%"},
-    "iib_interlocks_3": {"addr": 104, "format": "I", "size": 4, "egu": ""},
-    "iib_alarms_3": {"addr": 105, "format": "I", "size": 4, "egu": ""},
-    "v_input_iib_4": {"addr": 106, "format": "f", "size": 4, "egu": "V"},
-    "v_output_iib_4": {"addr": 107, "format": "f", "size": 4, "egu": "V"},
-    "i_igbt_1_iib_4": {"addr": 108, "format": "f", "size": 4, "egu": "A"},
-    "i_igbt_2_iib_4": {"addr": 109, "format": "f", "size": 4, "egu": "A"},
-    "temp_igbt_1_iib_4": {"addr": 110, "format": "f", "size": 4, "egu": "°C"},
-    "temp_igbt_2_iib_4": {"addr": 111, "format": "f", "size": 4, "egu": "°C"},
-    "v_driver_iib_4": {"addr": 112, "format": "f", "size": 4, "egu": "V"},
-    "i_driver_1_iib_4": {"addr": 113, "format": "f", "size": 4, "egu": "A"},
-    "i_driver_2_iib_4": {"addr": 114, "format": "f", "size": 4, "egu": "A"},
-    "temp_inductor_iib_4": {"addr": 115, "format": "f", "size": 4, "egu": "°C"},
-    "temp_heatsink_iib_4": {"addr": 116, "format": "f", "size": 4, "egu": "°C"},
-    "i_leakage_iib_4": {"addr": 117, "format": "f", "size": 4, "egu": "A"},
-    "temp_board_iib_4": {"addr": 118, "format": "f", "size": 4, "egu": "°C"},
-    "rh_iib_4": {"addr": 119, "format": "f", "size": 4, "egu": "%"},
-    "iib_interlocks_4": {"addr": 120, "format": "I", "size": 4, "egu": ""},
-    "iib_alarms_4": {"addr": 121, "format": "I", "size": 4, "egu": ""},
-    "ps_alarms": {"addr": 122, "format": "I", "size": 4, "egu": ""},
+    "temp_board_iib_2": {"addr": 85, "format": "f", "size": 4, "egu": "°C"},
+    "rh_iib_2": {"addr": 86, "format": "f", "size": 4, "egu": "%"},
+    "iib_interlocks_2": {"addr": 87, "format": "I", "size": 4, "egu": ""},
+    "iib_alarms_2": {"addr": 88, "format": "I", "size": 4, "egu": ""},
+    "v_input_iib_3": {"addr": 89, "format": "f", "size": 4, "egu": "V"},
+    "v_output_iib_3": {"addr": 90, "format": "f", "size": 4, "egu": "V"},
+    "i_igbt_1_iib_3": {"addr": 91, "format": "f", "size": 4, "egu": "A"},
+    "i_igbt_2_iib_3": {"addr": 92, "format": "f", "size": 4, "egu": "A"},
+    "temp_igbt_1_iib_3": {"addr": 93, "format": "f", "size": 4, "egu": "°C"},
+    "temp_igbt_2_iib_3": {"addr": 94, "format": "f", "size": 4, "egu": "°C"},
+    "v_driver_iib_3": {"addr": 95, "format": "f", "size": 4, "egu": "V"},
+    "i_driver_1_iib_3": {"addr": 96, "format": "f", "size": 4, "egu": "A"},
+    "i_driver_2_iib_3": {"addr": 97, "format": "f", "size": 4, "egu": "A"},
+    "temp_inductor_iib_3": {"addr": 98, "format": "f", "size": 4, "egu": "°C"},
+    "temp_heatsink_iib_3": {"addr": 99, "format": "f", "size": 4, "egu": "°C"},
+    "temp_board_iib_3": {"addr": 100, "format": "f", "size": 4, "egu": "°C"},
+    "rh_iib_3": {"addr": 101, "format": "f", "size": 4, "egu": "%"},
+    "iib_interlocks_3": {"addr": 102, "format": "I", "size": 4, "egu": ""},
+    "iib_alarms_3": {"addr": 103, "format": "I", "size": 4, "egu": ""},
+    "v_input_iib_4": {"addr": 104, "format": "f", "size": 4, "egu": "V"},
+    "v_output_iib_4": {"addr": 105, "format": "f", "size": 4, "egu": "V"},
+    "i_igbt_1_iib_4": {"addr": 106, "format": "f", "size": 4, "egu": "A"},
+    "i_igbt_2_iib_4": {"addr": 107, "format": "f", "size": 4, "egu": "A"},
+    "temp_igbt_1_iib_4": {"addr": 108, "format": "f", "size": 4, "egu": "°C"},
+    "temp_igbt_2_iib_4": {"addr": 109, "format": "f", "size": 4, "egu": "°C"},
+    "v_driver_iib_4": {"addr": 110, "format": "f", "size": 4, "egu": "V"},
+    "i_driver_1_iib_4": {"addr": 111, "format": "f", "size": 4, "egu": "A"},
+    "i_driver_2_iib_4": {"addr": 112, "format": "f", "size": 4, "egu": "A"},
+    "temp_inductor_iib_4": {"addr": 113, "format": "f", "size": 4, "egu": "°C"},
+    "temp_heatsink_iib_4": {"addr": 114, "format": "f", "size": 4, "egu": "°C"},
+    "temp_board_iib_4": {"addr": 115, "format": "f", "size": 4, "egu": "°C"},
+    "rh_iib_4": {"addr": 116, "format": "f", "size": 4, "egu": "%"},
+    "iib_interlocks_4": {"addr": 117, "format": "I", "size": 4, "egu": ""},
+    "iib_alarms_4": {"addr": 118, "format": "I", "size": 4, "egu": ""},
+    "ps_alarms": {"addr": 119, "format": "I", "size": 4, "egu": ""},
 }
 
 bsmp_2p2s = {
@@ -319,18 +316,18 @@ bsmp_2p2s = {
     "duty_cycle_2_3": {"addr": 61, "format": "f", "size": 4, "egu": "p.u."},
     "duty_cycle_1_4": {"addr": 62, "format": "f", "size": 4, "egu": "p.u."},
     "duty_cycle_2_4": {"addr": 63, "format": "f", "size": 4, "egu": "p.u."},
-    "v_input_iib_1": {"addr": 64, "format": "f", "size": 4, "egu": "V"},
-    "v_output_iib_1": {"addr": 65, "format": "f", "size": 4, "egu": "V"},
-    "i_igbt_1_iib_1": {"addr": 66, "format": "f", "size": 4, "egu": "A"},
-    "i_igbt_2_iib_1": {"addr": 67, "format": "f", "size": 4, "egu": "A"},
-    "temp_igbt_1_iib_1": {"addr": 68, "format": "f", "size": 4, "egu": "°C"},
-    "temp_igbt_2_iib_1": {"addr": 69, "format": "f", "size": 4, "egu": "°C"},
-    "v_driver_iib_1": {"addr": 70, "format": "f", "size": 4, "egu": "V"},
-    "i_driver_1_iib_1": {"addr": 71, "format": "f", "size": 4, "egu": "A"},
-    "i_driver_2_iib_1": {"addr": 72, "format": "f", "size": 4, "egu": "A"},
-    "temp_inductor_iib_1": {"addr": 73, "format": "f", "size": 4, "egu": "°C"},
-    "temp_heatsink_iib_1": {"addr": 74, "format": "f", "size": 4, "egu": "°C"},
-    "i_leakage_iib_1": {"addr": 75, "format": "f", "size": 4, "egu": "A"},
+    "i_leakage": {"addr": 64, "format": "f", "size": 4, "egu": "A"},
+    "v_input_iib_1": {"addr": 65, "format": "f", "size": 4, "egu": "V"},
+    "v_output_iib_1": {"addr": 66, "format": "f", "size": 4, "egu": "V"},
+    "i_igbt_1_iib_1": {"addr": 67, "format": "f", "size": 4, "egu": "A"},
+    "i_igbt_2_iib_1": {"addr": 68, "format": "f", "size": 4, "egu": "A"},
+    "temp_igbt_1_iib_1": {"addr": 69, "format": "f", "size": 4, "egu": "°C"},
+    "temp_igbt_2_iib_1": {"addr": 70, "format": "f", "size": 4, "egu": "°C"},
+    "v_driver_iib_1": {"addr": 71, "format": "f", "size": 4, "egu": "V"},
+    "i_driver_1_iib_1": {"addr": 72, "format": "f", "size": 4, "egu": "A"},
+    "i_driver_2_iib_1": {"addr": 73, "format": "f", "size": 4, "egu": "A"},
+    "temp_inductor_iib_1": {"addr": 74, "format": "f", "size": 4, "egu": "°C"},
+    "temp_heatsink_iib_1": {"addr": 75, "format": "f", "size": 4, "egu": "°C"},
     "temp_board_iib_1": {"addr": 76, "format": "f", "size": 4, "egu": "°C"},
     "rh_iib_1": {"addr": 77, "format": "f", "size": 4, "egu": "%"},
     "iib_interlocks_1": {"addr": 78, "format": "I", "size": 4, "egu": ""},
@@ -346,41 +343,39 @@ bsmp_2p2s = {
     "i_driver_2_iib_2": {"addr": 88, "format": "f", "size": 4, "egu": "A"},
     "temp_inductor_iib_2": {"addr": 89, "format": "f", "size": 4, "egu": "°C"},
     "temp_heatsink_iib_2": {"addr": 90, "format": "f", "size": 4, "egu": "°C"},
-    "ps_alarms": {"addr": 91, "format": "I", "size": 4, "egu": ""},
-    "temp_board_iib_2": {"addr": 92, "format": "f", "size": 4, "egu": "°C"},
-    "rh_iib_2": {"addr": 93, "format": "f", "size": 4, "egu": "%"},
-    "iib_interlocks_2": {"addr": 94, "format": "I", "size": 4, "egu": ""},
-    "iib_alarms_2": {"addr": 95, "format": "I", "size": 4, "egu": ""},
-    "v_input_iib_3": {"addr": 96, "format": "f", "size": 4, "egu": "V"},
-    "v_output_iib_3": {"addr": 97, "format": "f", "size": 4, "egu": "V"},
-    "i_igbt_1_iib_3": {"addr": 98, "format": "f", "size": 4, "egu": "A"},
-    "i_igbt_2_iib_3": {"addr": 99, "format": "f", "size": 4, "egu": "A"},
-    "temp_igbt_1_iib_3": {"addr": 100, "format": "f", "size": 4, "egu": "°C"},
-    "temp_igbt_2_iib_3": {"addr": 101, "format": "f", "size": 4, "egu": "°C"},
-    "v_driver_iib_3": {"addr": 102, "format": "f", "size": 4, "egu": "V"},
-    "i_driver_1_iib_3": {"addr": 103, "format": "f", "size": 4, "egu": "A"},
-    "i_driver_2_iib_3": {"addr": 104, "format": "f", "size": 4, "egu": "A"},
-    "temp_inductor_iib_3": {"addr": 105, "format": "f", "size": 4, "egu": "°C"},
-    "temp_heatsink_iib_3": {"addr": 106, "format": "f", "size": 4, "egu": "°C"},
-    "i_leakage_iib_3": {"addr": 107, "format": "f", "size": 4, "egu": "A"},
-    "temp_board_iib_3": {"addr": 108, "format": "f", "size": 4, "egu": "°C"},
-    "rh_iib_3": {"addr": 109, "format": "f", "size": 4, "egu": "%"},
-    "iib_interlocks_3": {"addr": 110, "format": "I", "size": 4, "egu": ""},
-    "iib_alarms_3": {"addr": 111, "format": "I", "size": 4, "egu": ""},
-    "v_input_iib_4": {"addr": 112, "format": "f", "size": 4, "egu": "V"},
-    "v_output_iib_4": {"addr": 113, "format": "f", "size": 4, "egu": "V"},
-    "i_igbt_1_iib_4": {"addr": 114, "format": "f", "size": 4, "egu": "A"},
-    "i_igbt_2_iib_4": {"addr": 115, "format": "f", "size": 4, "egu": "A"},
-    "temp_igbt_1_iib_4": {"addr": 116, "format": "f", "size": 4, "egu": "°C"},
-    "temp_igbt_2_iib_4": {"addr": 117, "format": "f", "size": 4, "egu": "°C"},
-    "v_driver_iib_4": {"addr": 118, "format": "f", "size": 4, "egu": "V"},
-    "i_driver_1_iib_4": {"addr": 119, "format": "f", "size": 4, "egu": "A"},
-    "i_driver_2_iib_4": {"addr": 120, "format": "f", "size": 4, "egu": "A"},
-    "temp_inductor_iib_4": {"addr": 121, "format": "f", "size": 4, "egu": "°C"},
-    "temp_heatsink_iib_4": {"addr": 122, "format": "f", "size": 4, "egu": "°C"},
-    "i_leakage_iib_4": {"addr": 123, "format": "f", "size": 4, "egu": "A"},
-    "temp_board_iib_4": {"addr": 124, "format": "f", "size": 4, "egu": "°C"},
-    "rh_iib_4": {"addr": 125, "format": "f", "size": 4, "egu": "%"},
-    "iib_interlocks_4": {"addr": 126, "format": "I", "size": 4, "egu": ""},
-    "iib_alarms_4": {"addr": 127, "format": "I", "size": 4, "egu": ""},
+    "temp_board_iib_2": {"addr": 91, "format": "f", "size": 4, "egu": "°C"},
+    "rh_iib_2": {"addr": 92, "format": "f", "size": 4, "egu": "%"},
+    "iib_interlocks_2": {"addr": 93, "format": "I", "size": 4, "egu": ""},
+    "iib_alarms_2": {"addr": 94, "format": "I", "size": 4, "egu": ""},
+    "v_input_iib_3": {"addr": 95, "format": "f", "size": 4, "egu": "V"},
+    "v_output_iib_3": {"addr": 96, "format": "f", "size": 4, "egu": "V"},
+    "i_igbt_1_iib_3": {"addr": 97, "format": "f", "size": 4, "egu": "A"},
+    "i_igbt_2_iib_3": {"addr": 98, "format": "f", "size": 4, "egu": "A"},
+    "temp_igbt_1_iib_3": {"addr": 99, "format": "f", "size": 4, "egu": "°C"},
+    "temp_igbt_2_iib_3": {"addr": 100, "format": "f", "size": 4, "egu": "°C"},
+    "v_driver_iib_3": {"addr": 101, "format": "f", "size": 4, "egu": "V"},
+    "i_driver_1_iib_3": {"addr": 102, "format": "f", "size": 4, "egu": "A"},
+    "i_driver_2_iib_3": {"addr": 103, "format": "f", "size": 4, "egu": "A"},
+    "temp_inductor_iib_3": {"addr": 104, "format": "f", "size": 4, "egu": "°C"},
+    "temp_heatsink_iib_3": {"addr": 105, "format": "f", "size": 4, "egu": "°C"},
+    "temp_board_iib_3": {"addr": 106, "format": "f", "size": 4, "egu": "°C"},
+    "rh_iib_3": {"addr": 107, "format": "f", "size": 4, "egu": "%"},
+    "iib_interlocks_3": {"addr": 108, "format": "I", "size": 4, "egu": ""},
+    "iib_alarms_3": {"addr": 109, "format": "I", "size": 4, "egu": ""},
+    "v_input_iib_4": {"addr": 110, "format": "f", "size": 4, "egu": "V"},
+    "v_output_iib_4": {"addr": 111, "format": "f", "size": 4, "egu": "V"},
+    "i_igbt_1_iib_4": {"addr": 112, "format": "f", "size": 4, "egu": "A"},
+    "i_igbt_2_iib_4": {"addr": 113, "format": "f", "size": 4, "egu": "A"},
+    "temp_igbt_1_iib_4": {"addr": 114, "format": "f", "size": 4, "egu": "°C"},
+    "temp_igbt_2_iib_4": {"addr": 115, "format": "f", "size": 4, "egu": "°C"},
+    "v_driver_iib_4": {"addr": 116, "format": "f", "size": 4, "egu": "V"},
+    "i_driver_1_iib_4": {"addr": 117, "format": "f", "size": 4, "egu": "A"},
+    "i_driver_2_iib_4": {"addr": 118, "format": "f", "size": 4, "egu": "A"},
+    "temp_inductor_iib_4": {"addr": 119, "format": "f", "size": 4, "egu": "°C"},
+    "temp_heatsink_iib_4": {"addr": 120, "format": "f", "size": 4, "egu": "°C"},
+    "temp_board_iib_4": {"addr": 121, "format": "f", "size": 4, "egu": "°C"},
+    "rh_iib_4": {"addr": 122, "format": "f", "size": 4, "egu": "%"},
+    "iib_interlocks_4": {"addr": 123, "format": "I", "size": 4, "egu": ""},
+    "iib_alarms_4": {"addr": 124, "format": "I", "size": 4, "egu": ""},
+    "ps_alarms": {"addr": 125, "format": "I", "size": 4, "egu": ""},
 }
